package intl;

import java.text.AttributedCharacterIterator;

public class TextAttribute extends AttributedCharacterIterator.Attribute {

    /** Construct a TextAttribute key with name s */
    public TextAttribute(String s) {
        super(s);
    }

    public final static TextAttribute FLOW_PARAGRAPH =
        new TextAttribute("FLOW_PARAGRAPH");

    public final static TextAttribute FLOW_EMPTY_PARAGRAPH =
        new TextAttribute("FLOW_EMPTY_PARAGRAPH");

    public final static TextAttribute FLOW_LINE_BREAK =
        new TextAttribute("FLOW_LINE_BREAK");

    public final static TextAttribute FLOW_REGIONS =
        new TextAttribute("FLOW_REGIONS");

    public final static TextAttribute LINE_HEIGHT =
        new TextAttribute("LINE_HEIGHT");

    public final static TextAttribute PREFORMATTED =
        new TextAttribute("PREFORMATTED");

    /** Attribute span delimiter - new tspan, tref, or textelement.*/
    public final static TextAttribute TEXT_COMPOUND_DELIMITER =
                          new TextAttribute("TEXT_COMPOUND_DELIMITER");

    /** Element identifier all chars from same element will share an
     *  ID. */
    public final static TextAttribute TEXT_COMPOUND_ID =
                          new TextAttribute("TEXT_COMPOUND_ID");

    /** Anchor type.*/
    public final static TextAttribute ANCHOR_TYPE =
                          new TextAttribute("ANCHOR_TYPE");

    /** Marker attribute indicating explicit glyph layout.*/
    public final static TextAttribute EXPLICIT_LAYOUT =
                          new TextAttribute("EXPLICIT_LAYOUT");

    /** User-space X coordinate for character.*/
    public final static TextAttribute X = new TextAttribute("X");

    /** User-space Y coordinate for character.*/
    public final static TextAttribute Y = new TextAttribute("Y");

    /** User-space relative X coordinate for character.*/
    public final static TextAttribute DX = new TextAttribute("DX");

    /** User-space relative Y coordinate for character.*/
    public final static TextAttribute DY = new TextAttribute("DY");

    /** Rotation for character, in degrees.*/
    public final static TextAttribute ROTATION =
                                      new TextAttribute("ROTATION");

    /** All the paint attributes for the text.*/
    public final static TextAttribute PAINT_INFO =
                                      new TextAttribute("PAINT_INFO");

    /** Author-expected width for bounding box containing
     *  all text string glyphs.
     */
    public final static TextAttribute BBOX_WIDTH =
                                      new TextAttribute("BBOX_WIDTH");

    /** Method specified for adjusting text element layout size.
     */
    public final static TextAttribute LENGTH_ADJUST =
                                      new TextAttribute("LENGTH_ADJUST");

    /** Convenience flag indicating that non-default glyph spacing is needed.
     */
    public final static TextAttribute CUSTOM_SPACING =
                                      new TextAttribute("CUSTOM_SPACING");

    /** User-specified inter-glyph kerning value.
     */
    public final static TextAttribute KERNING =
                                      new TextAttribute("KERNING");

    /** User-specified inter-glyph spacing value.
     */
    public final static TextAttribute LETTER_SPACING =
                                      new TextAttribute("LETTER_SPACING");

    /** User-specified width for whitespace characters.
     */
    public final static TextAttribute WORD_SPACING =
                                      new TextAttribute("WORD_SPACING");

    /** Path along which text is to be laid out */
    public final static TextAttribute TEXTPATH =
                                      new TextAttribute("TEXTPATH");

    /** Font variant to be used for this character span.
     * @see org.apache.batik.gvt.text.GVTAttributedCharacterIterator.TextAttribute#SMALL_CAPS
     */
    public final static TextAttribute FONT_VARIANT =
                                      new TextAttribute("FONT_VARIANT");

    /** Baseline adjustment to be applied to this character span.
     */
    public final static TextAttribute BASELINE_SHIFT =
                                      new TextAttribute("BASELINE_SHIFT");

    /** Directional writing mode applied to this character span.
     */
    public final static TextAttribute WRITING_MODE =
                                      new TextAttribute("WRITING_MODE");

    public final static TextAttribute VERTICAL_ORIENTATION =
                                      new TextAttribute("VERTICAL_ORIENTATION");

    public final static TextAttribute VERTICAL_ORIENTATION_ANGLE =
                                      new TextAttribute("VERTICAL_ORIENTATION_ANGLE");

    public final static TextAttribute HORIZONTAL_ORIENTATION_ANGLE =
                                      new TextAttribute("HORIZONTAL_ORIENTATION_ANGLE");

    public final static TextAttribute GVT_FONT_FAMILIES =
                   new TextAttribute("GVT_FONT_FAMILIES");

    public final static TextAttribute GVT_FONTS =
                                      new TextAttribute("GVT_FONTS");

    public final static TextAttribute GVT_FONT =
                                      new TextAttribute("GVT_FONT");

    public final static TextAttribute ALT_GLYPH_HANDLER =
                                      new TextAttribute("ALT_GLYPH_HANDLER");

    public final static TextAttribute BIDI_LEVEL =
                                      new TextAttribute("BIDI_LEVEL");

    public final static TextAttribute CHAR_INDEX =
                                      new TextAttribute("CHAR_INDEX");

    public final static TextAttribute ARABIC_FORM =
                                      new TextAttribute("ARABIC_FORM");

    // VALUES

    /** Value for WRITING_MODE indicating left-to-right */
    public final static Integer WRITING_MODE_LTR = new Integer(0x1);

    /** Value for WRITING_MODE indicating right-to-left */
    public final static Integer WRITING_MODE_RTL = new Integer(0x2);

    /** Value for WRITING_MODE indicating top-to-botton */
    public final static Integer WRITING_MODE_TTB = new Integer(0x3);

    /** Value for VERTICAL_ORIENTATION indicating an angle */
    public final static Integer ORIENTATION_ANGLE = new Integer(0x1);

    /** Value for VERTICAL_ORIENTATION indicating auto */
    public final static Integer ORIENTATION_AUTO = new Integer(0x2);

    /** Value for FONT_VARIANT specifying small caps */
    public final static Integer SMALL_CAPS = new Integer(0x10);

    /** Value for UNDERLINE specifying underlining-on */
    public final static Integer UNDERLINE_ON =
                        java.awt.font.TextAttribute.UNDERLINE_ON;

    /** Value for OVERLINE specifying overlining-on */
    public final static Boolean OVERLINE_ON = new Boolean(true);

    /** Value for STRIKETHROUGH specifying strikethrough-on */
    public final static Boolean STRIKETHROUGH_ON =
                        java.awt.font.TextAttribute.STRIKETHROUGH_ON;

    /** Value for LENGTH_ADJUST specifying adjustment to inter-glyph spacing */
    public final static Integer ADJUST_SPACING =
                        new Integer(0x0);

    /** Value for LENGTH_ADJUST specifying overall scaling of layout outlines */
    public final static Integer ADJUST_ALL =
                        new Integer(0x01);

    // constant values for the arabic glyph forms
    public final static Integer ARABIC_NONE = new Integer(0x0);
    public final static Integer ARABIC_ISOLATED = new Integer(0x1);
    public final static Integer ARABIC_TERMINAL = new Integer(0x2);
    public final static Integer ARABIC_INITIAL = new Integer(0x3);
    public final static Integer ARABIC_MEDIAL = new Integer(0x4);

}
